package ru.dbotthepony.mc.otm.screen;

import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.TranslatableComponent;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.item.ItemStack;
import ru.dbotthepony.mc.otm.menu.DriveViewerMenu;
import ru.dbotthepony.mc.otm.menu.MatteryMenu;
import ru.dbotthepony.mc.otm.menu.slot.BatterySlot;
import ru.dbotthepony.mc.otm.menu.slot.MatterySlot;
import ru.dbotthepony.mc.otm.menu.widget.GaugeWidget;
import ru.dbotthepony.mc.otm.screen.panels.*;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

public class DriveViewerScreen extends MatteryScreen<DriveViewerMenu> implements MatteryScreen.IMatteryScreenGaugeGetter, MatteryScreen.IMatteryScreenBatteryGetter {
	public static final int FRAME_WIDTH = 210;
	public static final int FRAME_HEIGHT = 110;

	public static final int GRID_WIDTH = 9;
	public static final int GRID_HEIGHT = 5;

	public DriveViewerScreen(DriveViewerMenu menu, Inventory inventory, Component title) {
		super(menu, inventory, title);
	}

	@Override
	public List<GaugeWidget> getGauges() {
		return List.of(menu.battery_widget);
	}

	@Override
	public List<MatterySlot> getBatterySlots() {
		return List.of(menu.battery_slot, menu.drive_slot);
	}

	@Nullable
	@Override
	protected FramePanel makeMainFrame() {
		var frame = new FramePanel(this, null, 0, 0, FRAME_WIDTH, FRAME_HEIGHT, getTitle());

		autoAttachToFrame(frame);

		var grid = new GridPanel(this, frame, 0, 0, 0, 0, GRID_WIDTH, GRID_HEIGHT);
		grid.setDock(Dock.FILL);
		grid.setDockMargin(2, 2, 2, 2);
		var scroll_bar = new ScrollBarPanel(this, frame, 0, 0, 0);
		scroll_bar.setDock(Dock.RIGHT);
		scroll_bar.setupRowMultiplier(() -> {
			var view = menu.getView();

			if (view != null) {
				return view.getItems().size() / GRID_WIDTH;
			}

			return 0;
		});

		for (int i = 0; i < GRID_WIDTH * GRID_HEIGHT; i++) {
			final int index = i;

			new AbstractSlotPanel(this, grid, 0, 0) {
				@Nonnull
				@Override
				protected ItemStack getItemStack() {
					int findex = index + scroll_bar.getScroll(GRID_WIDTH);

					var view = menu.getView();

					if (view != null) {
						var list = view.getItems();

						if (findex >= list.size()) {
							return ItemStack.EMPTY;
						}

						return list.get(findex);
					}

					return ItemStack.EMPTY;
				}

				@Override
				protected boolean mouseScrolledInner(double mouse_x, double mouse_y, double scroll) {
					return scroll_bar.mouseScrolledInner(mouse_x, mouse_y, scroll);
				}
			};
		}

		return frame;
	}
}
